Learn R Programming

rbranding (version 0.1.1)

brand_init: Initialize branding configuration

Description

brand_init initializes the branding configuration by creating two files:

  • rbranding_config.yml: contains remote and local file paths to brand files

  • _brand.yml: a placeholder branding file It is intended to be run once. Use a get_brand_*() function to download/update the brand file.

Usage

brand_init(brand_url = NULL, install_path = ".")

Value

NULL. Called for its side effects: downloading and creating rbranding_config.yml

and _brand.yml files.

Arguments

brand_url

Optional URL. Points to the remote brand file. If NULL, defaults to rbranding's brand file on GitHub.

install_path

Optional string. Directory where the files should be created. Defaults to the current working directory.

Examples

Run this code
tmpdir <- file.path(tempdir(), "brand_files")

brand_init(install_path = tmpdir)

# Clean up
unlink(tmpdir, recursive = TRUE)

Run the code above in your browser using DataLab