powered by
brand_init initializes the branding configuration by creating two files:
brand_init
rbranding_config.yml: contains remote and local file paths to brand files
rbranding_config.yml
_brand.yml: a placeholder branding file It is intended to be run once. Use a get_brand_*() function to download/update the brand file.
_brand.yml
get_brand_*()
brand_init(brand_url = NULL, install_path = ".")
NULL. Called for its side effects: downloading and creating rbranding_config.yml
and _brand.yml files.
Optional URL. Points to the remote brand file. If NULL, defaults to rbranding's brand file on GitHub.
NULL
Optional string. Directory where the files should be created. Defaults to the current working directory.
tmpdir <- file.path(tempdir(), "brand_files") brand_init(install_path = tmpdir) # Clean up unlink(tmpdir, recursive = TRUE)
Run the code above in your browser using DataLab